#!/bin/sh
#set -x
#echo platformgroupaff.sh
#
#  Please read the License and Disclaimer found in the Readme.txt file 
#  in the /usr/local/ASAM/bin/PlatformServices/PlatformReceiver/scripts
#  directory.
#
#  COPYRIGHT
#
#  Copyright @ 2002 Omnibond Systems, LLC.
#
#
# platformgroupaff.sh
#
#   record platform group affiliation of TARGETUSER
#

if [ "$DEBUGMODE" = "TRUE" ] ; then set -x ; fi

[ $FACILITY ]
if [ $? = "1" ] ; then exit 255 ; fi

# do some sanity checking on PARMFILE
[ $PARMFILE ]
if [ $? = "1" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not set"`
  exit 255
fi

DIRNAME=`dirname $PARMFILE`
if [ $DIRNAME != "/tmp" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not correct :"$PARMFILE":"`
  exit 255
fi

if [ -h $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo $PARMFILE" a symbolic link!"`
  exit 255
fi

if [ -f $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE exists!"`
  exit 255
fi 

[ "$TARGETUSER" ]
if [ $? = "1" ] 
then
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "TARGETUSER not set."`
  exit 255
fi 

GROUPS=`/bin/groups $TARGETUSER`

# /bin/groups returns a space separated list of groups that the user
# is in. We want to map that to a list of tuples, one per line, 
# that look like:    group,gid
#
# All users at least have a primary group affiliation, which is
# the first in the list. The primary group is ignored, only
# the other groups (if any) are used.
#
FIRSTTIME=0
for i in `echo $GROUPS`
do
  if [ $FIRSTTIME = "1" ]
  then
    GID=`/bin/grep "^$i:" /etc/group | /bin/awk -F: '{ print $3 }'`
    [ $GID ]
    if [ $? = "0" ]
    then
      echo "$i,$GID">>$PARMFILE
    else
      echo "$i,-1">>$PARMFILE
    fi
  fi
  FIRSTTIME=1
done

# Users might be in some roles. From the perspective of
# this script, we treat roles like groups with no gids. 
# add any corresponding groupnames of TARGETUSER's roles to the PARMFILE.

DATADIR=/usr/local/ASAM/data
RECORD=`grep $TARGETUSER /etc/user_attr`
NF=`echo $RECORD | awk -F\; '{ print NF }'`
echo "NF="$NF
I=1
while [ $I -le $NF ]
do
  # if TARGETUSER is a role-user, don't bother checking to see
  # if he is in any roles.
  if [ "$URBAC" != "" ] ; then break ; fi
  COMMAND="echo \$RECORD | awk -F\; '{ print \$"$I" }'"
  FIELD=`eval $COMMAND` 
  echo $FIELD | grep "roles=" > /dev/null
  if [ $? = "0" ]
  then
    ROLES=`echo $FIELD | awk -F= '{ print $2 }'`
    IFSSAVE=$IFS
    IFS=$IFS","
    for ROLE in `echo $ROLES`
    do
      IFS=$IFSSAVE
      # map rolename to corresponding groupname 
      FQN=""
      RNTOGN=""
      FQN=`/bin/find $DATADIR/d.rolemap -type f \
           -exec /usr/xpg4/bin/grep -q \^"$ROLE"\$ {} \; -print`
      RNTOGN=`basename $FQN`
      if [ "$RNTOGN" != "" ] ; then echo $RNTOGN",-1" >>$PARMFILE ; fi
    done
  fi
  I=`expr $I + 1` 
done

echo "EOFMARKER">>$PARMFILE
exit 0
