#!/bin/sh
#set -x
#echo platformgroupmem.sh
#
#  Please read the License and Disclaimer found in the Readme.txt file 
#  in the /usr/local/ASAM/bin/PlatformServices/PlatformReceiver/scripts
#  directory.
#
#  COPYRIGHT
#
#  Copyright @ 2002 Omnibond Systems, LLC.
#
#
# platformgroupmem.sh
#
#   record platform users in TARGETGROUP
#

if [ "$DEBUGMODE" = "TRUE" ] ; then set -x ; fi

[ $FACILITY ]
if [ $? = "1" ] ; then exit 255 ; fi

# do some sanity checking on PARMFILE
[ $PARMFILE ]
if [ $? = "1" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not set"`
  exit 255
fi

DIRNAME=`dirname $PARMFILE`
if [ $DIRNAME != "/tmp" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not correct :"$PARMFILE":"`
  exit 255
fi

if [ -h $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo $PARMFILE" a symbolic link!"`
  exit 255
fi

if [ -f $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE exists!"`
  exit 255
fi 

[ "$TARGETGROUP" ]
if [ $? = "1" ] 
then
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "TARGETGROUP not set."`
  exit 255
fi 

# /etc/group group members
EGGROUP=`/bin/grep "^$TARGETGROUP:" /etc/group | /bin/awk -F: '{ print $4 }'`

IFSSAVE=$IFS
IFS=$IFS","
for i in `echo $EGGROUP`
do
  IFS=$IFSSAVE
  # there could potentially be trash in /etc/group, ignore any
  # users found there that don't actually exist on the system
  /bin/id $i > /dev/null 2>&1
  if [ $? = "0" ]
  then
    # emit user names and uids of validated group members
    echo $i","`/bin/grep "^$i:" /etc/passwd |\
               /bin/awk -F: '{ print $3 }'`>>$PARMFILE
  fi
done

# grope around in /etc/user_attr for RBAC users who are
# associated with a role that might be represented by TARGETGROUP.
if [ "$GRBAC" != "" ]
then
  while read RECORD
  do
    echo $RECORD | grep "roles=" >/dev/null
    if [ $? = "0" ]
    then
      USER=`echo $RECORD|/bin/awk -F: '{ print $1 }'`
      NF=`echo $RECORD | awk -F\; '{ print NF }'`
      I=1
      while [ $I -le $NF ]
      do
        COMMAND="echo \$RECORD | awk -F\; '{ print \$"$I" }'"
        FIELD=`eval $COMMAND`
        echo $FIELD | grep "roles=" > /dev/null
        if [ $? = "0" ]
        then
          ROLES=`echo $FIELD | /bin/awk -F= '{ print $2 }'`
          IFSSAVE=$IFS
          IFS=$IFS","
          for ROLE in `echo $ROLES`
          do
            IFS=$IFSSAVE
            if [ "$ROLE" = "$GRBAC" ]
            then
              grep "^$USER:" /etc/passwd > /dev/null
              if [ $? = "0" ]
              then
                UID=`grep "^$USER:" /etc/passwd|/bin/awk -F: '{ print $3 }'`
                echo $USER,$UID>>$PARMFILE
              fi
            fi
          done
        fi
        I=`expr $I + 1` 
      done
    fi
  done < /etc/user_attr
fi

echo "EOFMARKER">>$PARMFILE
exit 0
