#!/bin/sh
#set -x
#echo platformverifyandmapname.sh
#
#  Please read the License and Disclaimer found in the Readme.txt file 
#  in the /usr/local/ASAM/bin/PlatformServices/PlatformReceiver/scripts
#  directory.
#
#  COPYRIGHT
#
#  Copyright @ 2002 Omnibond Systems, LLC.
#
#
# solaris/rbac version of platformverifyandmapname.sh
#
# Max length for user or group name set to 8

if [ "$DEBUGMODE" = "TRUE" ] ; then set -x ; fi

[ "$FACILITY" ]
if [ $? = "1" ] ; then exit 255 ; fi

[ "$VERIFY" ]
if [ $? = "1" ] ; then exit 255 ; fi

[ "$TYPE" ]
if [ $? = "1" ] ; then exit 255 ; fi

MAXL=8
LEN=0
AUTH=1
PROF=1
ROLE=1

if [ "$TRBAC" = "auth" ] ; then AUTH=0 ; fi
if [ "$TRBAC" = "prof" ] ; then PROF=0 ; fi
if [ "$TRBAC" = "role" ] ; then ROLE=0 ; fi
if [ "$URBAC" = "TRUE" ] ; then ROLE=0 ; fi

#if not auth, prof or role group, measure length
if [ "$TRBAC" = "" ] 
then 
  LEN=`echo $VERIFY|awk '{ print length($0) }'`
fi

# remember if an auth or prof or role
MASK=`expr $AUTH + $PROF + $ROLE`

if [ $LEN -gt $MAXL ]
then
  if  [ $MASK -eq 3 ]
  then
    /bin/logger -p $FACILITY.notice -t $0 -i \
      `echo $VERIFY" too long, max lenth = "$MAXL`
    exit 1
  fi
fi
# 
# require first character in user or group name to be alpha
char1=`echo $VERIFY|awk '{ print substr($1,1,1) }'`
case $char1 in

  *[A-Za-z] ) break
              ;;
  
  *)  /bin/logger -p $FACILITY.notice -t $0 -i \
        `echo "group and usernames must begin with an alpha: "$VERIFY`
      exit 1
      ;;
esac


if [ $MASK -eq 3 ]
then
  PA=""
  INDEX="1"
  while [ 1 ] 
  do
    # change awk's FS to : so that names with spaces will flow through
    # this next pipeline properly. If you plan to support user or group
    # names with :'s in them (bizarre!) you'll have to set FS to something
    # else.
    char=`echo $VERIFY":"$INDEX |awk -F: '{ print substr($1,$2,1) }'`
    #
    # user names and group names have different sets of valid characters
    if [ $TYPE = "u" ]
    then
  
      case $char in
    
        *[0-9a-z._-]* ) 
           PA=$PA$char
           ;;
    
        *[A-Z]* )
           PA=$PA`/bin/echo $char|/usr/bin/tr '[A-Z]' '[a-z]'`
           ;;
  
        *) /bin/logger -p $FACILITY.notice -t $0 -i \
             `echo $char" is an invalid character for a user name"`
           exit 1
           ;;
    
      esac
  
    else
  
      case $char in
    
        *[0-9a-z]* ) 
           PA=$PA$char
           ;;
    
        *[A-Z]* )
           PA=$PA`/bin/echo $char|/usr/bin/tr '[A-Z]' '[a-z]'`
           ;;
  
        *) /bin/logger -p $FACILITY.notice -t $0 -i \
               `echo $char" is an invalid character for a group name"`
             exit 1
           ;;
    
      esac
    fi
  
    INDEX=`expr $INDEX + 1` 
    if [ $INDEX -gt $LEN ] ; then  break ; fi
  done
else # must be an auth or a prof or a role
  PA=$VERIFY
fi

# sometimes we don't need to return the mapped value
[ "$DONTMAP" ]
if [ $? = "0" ] ; then exit 0 ; fi

# output PA to file for xfer back to receiver

[ "$PARMFILE" ]
if [ $? = "1" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not set"`
  exit 255
fi

DIRNAME=`dirname $PARMFILE`
if [ $DIRNAME != "/tmp" ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE not correct :"$PARMFILE":"`
  exit 255
fi

if [ -h $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo $PARMFILE" a symbolic link!"`
  exit 255
fi

if [ -f $PARMFILE ] 
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "PARMFILE exists!"`
  exit 255
fi 

[ "$PA" ] 
if [ $? = "1" ]
then 
  /bin/logger -p $FACILITY.notice -t $0 -i \
    `echo "platform association not set or zero length!"`
  exit 255
fi 

echo "$PA">$PARMFILE
echo "EOFMARKER">>$PARMFILE

exit 0
