#!/bin/sh
#set -x
#echo populategroup.sh
#
#  Please read the License and Disclaimer found in the Readme.txt file 
#  in the /usr/local/ASAM/bin/PlatformServices/PlatformReceiver/scripts
#  directory.
#
#  COPYRIGHT
#
#  Copyright @ 2002 Omnibond Systems, LLC.
#
#
# populategroup.sh
# ASAMULIST - users ASAM thinks should be in target group
# PULIST - users currently in target group
# MANAGED - pertinent un-excluded managed users
# TARGETULIST - users to be added to group
#
# pupose - populate a group, taking into account who might currently be 
#          in the group, who ASAM thinks should be in the group, and
#          who is managed.
#
# example -
#
#   ASAMULIST="booboo,randy,bill"
#   PULIST="hubcap,randy,jeremy"
#   MANAGED="randy,booboo,jeremy"
#
#   is PULIST in MANAGED?
#      no ----> TARGETULIST
#      yes ---> in ASAMULIST?
#               no ----> DELETEULIST
#
#   is ASAMULIST in MANAGED?
#      yes ---> TARGETULIST
#
#   TARGETULIST="hubcap,booboo,randy"
#

if [ "$DEBUGMODE" = "TRUE" ] ; then set -x ; fi

# don't treat auths, profs or roles like groups
if [ "$GRBAC" != "" ] ; then exit $NOTHINGTODO ; fi

# see if there's anything to do.
[ "$ASAMULIST" ]
if [ $? = "1" ] ; then exit $NOTHINGTODO ; fi

# IFS denotes the characters the shell will classify as a blank.
# Typically IFS characters are space, tab and newline.
# Some of the time, during the execution of this script, a comma
# will also be a valid IFS character, so that the control structures
# will percieve comma-separated-list-items as separate words.
IFSSAVE=$IFS
IFS=$IFS","
TARGETULIST=""
DELETEULIST=""
for i in `echo $PULIST`
do
  FOUND="0"
  for j in `echo $MANAGED`
  do
    if [ $i = $j ] ; then FOUND="1" ; fi
  done
  if [ $FOUND = "0" ] 
  then 
    IFS=$IFSSAVE
    [ "$TARGETULIST" ]
    if [ $? = "1" ]
    then
      TARGETULIST=$i 
    else
      TARGETULIST=$TARGETULIST","$i 
    fi
    IFS=$IFS","
  else
    FOUND="0"
    for k in `echo $ASAMULIST`
    do
      if [ $i = $k ] ; then FOUND="1" ; fi
    done 
    if [ $FOUND = "0" ] ; then DELETEULIST=$DELETEULIST$i" " ; fi
  fi
done
for i in `echo $ASAMULIST`
do
  FOUND="0"
  for j in `echo $MANAGED`
  do
    if [ $i = $j ] 
    then
      IFS=$IFSSAVE
      FOUND="1"
      [ "$TARGETULIST" ]
      if [ $? = "1" ]
      then
        TARGETULIST=$i
      else
        TARGETULIST=$TARGETULIST","$i
      fi
      IFS=$IFS","
    fi
  done
  if [ $FOUND = "0" ]
  then 
    /bin/logger -p $FACILITY.notice -t $0 -i \
       echo $i" not added to "$TARGETGROUP", excluded from consideration."
  fi
done
#
# Each user in TARGETULIST needs to be added to TARGETGROUP.
# Using "usermod -g -G" we can set each user's group affiliation
# to include TARGETGROUP. 
#
#  Fetch each user's group affiliation and modify it by TARGETGROUP.
#  Express modified group affiliation as PRIMARY and SUPPLEMENTARY.
#  usermod -g PRIMARY -G SUPPLEMENTARY user.
#
#echo "TARGETULIST:"$TARGETULIST":"
#echo "ASAMULIST:"$ASAMULIST":"
#echo "PULIST:"$PULIST":"
#echo "MANAGED:"$MANAGED":"
#echo "DELETEULIST:"$DELETEULIST":"
#
for i in $TARGETULIST
do
  /bin/id $i > /dev/null 2>&1
  if [ $? = "0" ]
  then
    IFS=$IFSSAVE
    COMMAND="/usr/sbin/usermod "
    PRIMARY=""
    SUPPLEMENTARY=""
    DONE="0"
    RC=$NOTHINGTODO
    for j in `groups $i`
    do

      if [ $j = $TARGETGROUP ] ; then DONE="1" ; fi # user already in group
      [ "$PRIMARY" ]
      if [ $? = "1" ]
      then
        # example: usermod -g 99 user
        # on Solaris8, if a numeric gid less than 100 that isn't associated 
        # with a group in /etc/groups is specified, usermod DUMPS CORE. 
        # Since user's might have primary groups
        # that aren't in /etc/group, we have to be very careful.
        # We'll ignore PRIMARY groups that are numeric, since they
        # won't ever conflict with the managed group we are adding.
        FOUND=`/bin/grep "^$j:" /etc/group`
        [ "$FOUND" ]
        if [ $? = "1" ]
        then
          PRIMARY="UNUSABLEPRIMARY"
        else
          PRIMARY=$j
        fi
      else
        [ "$SUPPLEMENTARY" ]
        if [ $? = "1" ]
        then
          SUPPLEMENTARY=$j
        else
          SUPPLEMENTARY=$SUPPLEMENTARY","$j
        fi
      fi
    done
    if [ $DONE = "1" ]
    then
      FOUND="0"
      IFS=$IFS","
      for k in `echo $MANAGED`
      do
        if [ $i = $k ] ; then FOUND="1" ; fi
      done
      IFS=$IFSSAVE
      if [ $FOUND = "0" ] 
      then 
        /bin/logger -p $FACILITY.notice -t $0 -i \
          echo $i" already in group "$TARGETGROUP", excluded from consideration."
      else
        /bin/logger -p $FACILITY.notice -t $0 -i \
          echo $i" already in group "$TARGETGROUP", no need to add."
      fi
    else
      [ "$SUPPLEMENTARY" ]
      if [ $? = "1" ]
      then
        SUPPLEMENTARY=$TARGETGROUP
      else
        SUPPLEMENTARY=$SUPPLEMENTARY","$TARGETGROUP
      fi
      if [ "$PRIMARY" != "UNUSABLEPRIMARY" ]
      then
        COMMAND=$COMMAND" -g "$PRIMARY 
      fi
      [ "$SUPPLEMENTARY" ]
      if [ $? = "0" ] 
      then 
        COMMAND=$COMMAND" -G "$SUPPLEMENTARY 
      else
        COMMAND=$COMMAND" -G \"\"  "
      fi
      COMMAND=$COMMAND" "$i
  
      if [ "$CHECKMODE" ]  
      then 
        /bin/logger -p $FACILITY.notice -t $0 -i \
           `echo ":"$COMMAND":"`
      else
        eval $COMMAND
        RC=$?
        /bin/logger -p $FACILITY.notice -t $0 -i \
           `echo ":"$COMMAND": RC="$RC`
        if [ $RC -gt 0 ] ; then exit $RC; fi
      fi
    fi
    IFS=$IFS","
  else
    /bin/logger -p $FACILITY.notice -t $0 -i \
       echo $i" not on platform, can't add to "$TARGETGROUP"."
  fi 
done
#
# Each user in DELETEULIST needs to be removed from TARGETGROUP.
#
#  Fetch each user's group affiliation and modify it by TARGETGROUP.
#  Express modified group affiliation as PRIMARY and SUPPLEMENTARY.
#  usermod -g PRIMARY -G SUPPLEMENTARY user.
#
for i in $DELETEULIST
do
  /bin/id $i > /dev/null 2>&1
  if [ $? = "0" ]
  then
    IFS=$IFSSAVE
    COMMAND="/usr/sbin/usermod "
    PRIMARY=""
    SUPPLEMENTARY=""
    DOIT="0"
    for j in `groups $i`
    do

      [ "$PRIMARY" ]
      if [ $? = "1" ]
      then
        PRIMARY=$j
      else
        if [ $TARGETGROUP != $j ]
        then
          [ "$SUPPLEMENTARY" ]
          if [ $? = "1" ]
          then
            SUPPLEMENTARY=$j
          else
            SUPPLEMENTARY=$SUPPLEMENTARY","$j
          fi
        fi
      fi
    done
    if [ $PRIMARY = $TARGETGROUP ]
    then
      /bin/logger -p $FACILITY.notice -t $0 -i \
        $PRIMARY" is "$i"'s primary group, can't delete "$i" from "$PRIMARY"."
    else
      COMMAND=$COMMAND" -g "$PRIMARY
      [ $SUPPLEMENTARY ]
      if [ $? = "0" ]
      then
        COMMAND=$COMMAND" -G "$SUPPLEMENTARY
      else
        COMMAND=$COMMAND" -G \"\"  "
      fi
      COMMAND=$COMMAND" "$i
      DOIT="1"
    fi
  
    if [ $DOIT = "1" ]
    then
      if [ "$CHECKMODE" ]  
      then 
        /bin/logger -p $FACILITY.notice -t $0 -i \
           `echo ":"$COMMAND":"`
      else
        eval $COMMAND
        RC=$?
        /bin/logger -p $FACILITY.notice -t $0 -i \
           `echo ":"$COMMAND": RC="$RC`
        if [ $RC -gt 0 ] ; then exit $RC; fi

      fi
    fi
  fi
done
IFS=$IFSSAVE
exit $RC
